@@ -4,10 +4,7 @@ import sys
 from pathlib import Path
 __env_path__ = Path.home() / ".tradologics"
 
-try:
-    from .envdev import ENVIRONMENT
-except ImportError:
-    from .env import ENVIRONMENT
+from .env import ENVIRONMENT
 
 if ENVIRONMENT == "dev":
     __env_path__ = Path.home() / ".tradologics-dev"
@@ -31,10 +28,11 @@ from . import remote
 
 if "--version" in sys.argv or "-V" in sys.argv:
     data, errors = remote.api.get("/version", halt_on_error=False)
+    slug = "-dev" if ENVIRONMENT == "dev" else ""
     if data:
-        click.echo(f"\nTctl {version.version} / System {data['version']}")
+        click.echo(f"\nTctl {version.version}{slug} / System {data['version']}")
     else:
-        click.echo(f"\nTctl {version.version}")
+        click.echo(f"\nTctl {version.version}{slug}")
 
     click.echo("Copyrights (c) Tradologics, Inc.")
     click.echo("https://tradologics.com")
