@@ -19,7 +19,10 @@ def logo():
 
 @cli.command()
 @click.option('--delete', is_flag=True, help="Deletes token from disk.")
-def config(delete):
+@click.option('--key', help="API Key")
+@click.option('--secret', help="API Secret")
+@click.option('--dnt', default=False, is_flag=True, help="Track Install?", hidden=True)
+def config(delete, key, secret, dnt):
     """Initialize, authorize, and configure the tctl tool.
 
     Retreives and stores your token in as an encrypted file on disk.
@@ -27,4 +30,5 @@ def config(delete):
     if delete:
         credentials.delete()
 
-    return credentials.config(source="config")
+    return credentials.config(
+        source="config", api_key=key, api_secret=secret, dnt=dnt)
