@@ -24,6 +24,8 @@ rules.add_flags("usage", {
 
 
 def options_validator(ctx, param, args):
+    if not args:
+        args = ('info',)
     return utils.options_validator(args, commands, rules)
 
 
