@@ -19,7 +19,7 @@ commands = {
     "set-public": "   Make a strategy public: --strategy|-s {STRATEGY_ID}",
     "set-private": "   Make a strategy private: --strategy|-s {STRATEGY_ID}",
     "status": "  Display strategy status: --strategy|-s {STRATEGY_ID} [--start {YYYY-MM-DD}] [--end {YYYY-MM-DD}]",
-    "log": "     Show strategy deployment logs: --strategy|-s {STRATEGY_ID} [--lines|-l {NO}]",
+    "log": "     Show strategy deployment logs: --strategy|-s {STRATEGY_ID} [--lines|-l {NO=20}] [--live]",
     "report": "   Show strategy statistics: --strategy|-s {STRATEGY_ID}",
     "versions": "   Show strategy versions: --strategy|-s {STRATEGY_ID}",
     "version": "    Display strategy version: --strategy|-s {STRATEGY_ID} --version|-v {VERSION-ID} [--decode]",
@@ -46,7 +46,7 @@ rules.add_flags("version", {
 rules.add_optional("deploy", {"lang": ["-l", "--lang"]})
 rules.add_optional("set-mode", {"mode": ["-m", "--mode"]})
 rules.add_optional("log", {"lines": ["-l", "--lines"]})
-
+rules.add_flags("log", {"live": ["--live"]})
 
 
 def options_validator(ctx, param, args):
