@@ -13,6 +13,7 @@ from datetime import datetime
 import os
 import pandas as pd
 import dotenv
+import time
 
 dotenv.load_dotenv(__env_path__)
 pd.options.display.float_format = '{:,}'.format
@@ -97,21 +98,79 @@ def strategy_status(options):
     click.echo("\nStatus: {status}".format(status=data["status"].replace('_', ' ').title()))
 
 
+def _get_strategy_log(strategy, lines=10):
+    data, errors = remote.api.get(
+        f"/strategy/{strategy}/logs",
+        halt_on_error=False, ver_check=False)
+
+    if not errors:
+        if isinstance(data["logs"], str):
+            data["logs"] = [data["logs"]]
+
+        data["logs"] = data["logs"][-lines:]
+
+    return data, errors
+
+
 def strategy_log(options):
-    data, errors = remote.api.get("/strategy/{strategy}/logs".format(
-        strategy=options.first("strategy")))
+    default_lines = 20
+    lines = abs(int(options.first("lines", default_lines)))
 
-    lines = options.get("lines", [10])
-    data["logs"] = data["logs"][-abs(int(lines[0])):]
+    if options.first("live", False):
+        prev_log_ts = log_ts = ""
+        # prev_log_ts = "2021-03-24 18:13:00 Received Tradehook: bar"
+        occurrence = 0
 
-    if options.get("raw"):
+        while True:
+            if datetime.now().second in (4, 30) or occurrence == 0:
+                data, errors = _get_strategy_log(options.first("strategy"), lines)
+                if not errors:
+                    new_logs = "\n" + "\n".join(data["logs"])
+                    if prev_log_ts:
+                        new_logs = new_logs.rsplit(prev_log_ts, 1)[-1]
+
+                    # set last timestamp
+                    if occurrence == 0:
+                        new_logs = new_logs.rsplit(" Received Tradehook: ", 1)
+                    else:
+                        new_logs = new_logs.split(" Received Tradehook: ", 1)
+                    if len(new_logs) > 1:
+                        last_ts = new_logs[0].strip().rsplit("\n", 1)[-1]
+                        last_event = new_logs[1].strip().split("\n", 1)[0]
+                        log_ts = f"{last_ts} Received Tradehook: {last_event}"
+
+                    new_logs = "\n".join(new_logs)
+                    if occurrence > 0:
+                        new_logs = f"{log_ts}\n" + new_logs
+
+                    if prev_log_ts != log_ts:
+                        click.echo(
+                            new_logs.replace(' in: 0s', ' in: < 1s').replace(
+                                    '\nbar\n', ' Received Tradehook: bar\n')
+                        )
+                        occurrence += 1
+
+                    prev_log_ts = log_ts
+                    lines = 500
+            # else:
+            #     print(datetime.now().second)
+            time.sleep(1)
+        return
+
+    data, errors = _get_strategy_log(options.first("strategy"), lines)
+
+    if errors or options.get("raw"):
         click.echo(utils.to_json(data, errors))
         return
 
     if not data["logs"]:
         click.echo("\n[no logs]")
         return
-    click.echo("\n" + "\n".join(data["logs"]))
+
+    if lines > default_lines:
+        click.echo_via_pager("\n" + "\n".join(data["logs"]))
+    else:
+        click.echo("\n" + "\n".join(data["logs"]))
 
 
 def strategy_update(options):
