@@ -30,7 +30,7 @@ LANGS = {
     "python3": "Python 3",
     "python2": "Python 2",
     "node": "Node JS",
-    "go": "Go land",
+    "go": "Go Lang",
     "csharp": "C-Sharp",
     "php": "PHP 7",
     "ruby": "Ruby",
@@ -63,48 +63,19 @@ def strategy_deploy(options):
             click.echo("-----------------------------\n")
         lang = inputs.option_selector(
             "Language", LANGUAGES
-        ).replace(" ", "").replace("-", "").lower()
+        ).replace(" ", "").replace("-", "").lower().replace("nodejs", "node")
+
 
     # --- future ---
-    # path = inputs.path("Path to code directory", validator="directory")
-
-    # --- now ---
-    strategy_file_found = False
-    while not strategy_file_found:
-        strategy_file = inputs.path(
-            "Path to `{file}`".format(file=STRATEGY_FILES[lang]), validator="file")
-        strategy_file_found = Path(strategy_file).exists()
-
-    path = Path(strategy_file).parents[0]
-    dependencies = []
-    if "python" in lang:
-        dep_file = 'requirements.txt'
-        req_file = path / dep_file
-    elif "node" in lang:
-        dep_file = 'package.json'
-        req_file = path / dep_file
-
-    if req_file and req_file.is_file():
-        if inputs.confirm(
-                f"Found dependencies file `{dep_file}`. Import it?",
-                default=True):
-            dependencies = _read_dependencies(lang, str(path))
+    path = inputs.path("Path to code directory", validator="directory")
 
     # --- continue ---
     comment = inputs.text("Comment (optional)")
     active = inputs.confirm("Activate this version?", default=True)
 
-    payload = {
-        # "code": _prepare_deploy(lang, path),
-        "code": _read_file(strategy_file),
-        "dependencies": dependencies,
-        "lang": lang,
-        "comment": comment,
-        "active": active,
-    }
-
-    # print(utils.to_json(payload))
-    # return
+    payload = _prepare_deploy(lang, path)
+    payload["comment"] = comment
+    payload["active"] = active
 
     data, errors = remote.api.post(
         "/strategy/{strategy}/versions".format(strategy=strategy),
@@ -129,8 +100,7 @@ def _prepare_deploy(lang, directory):
     files = _read_files(directory, STRATEGY_FILES[lang])
     dependencies = _read_dependencies(lang, directory)
     return {
-        # "files": files,
-        "code": files[STRATEGY_FILES[lang]],
+        "files": files,
         "dependencies": dependencies,
         "lang": lang
     }
@@ -157,17 +127,21 @@ def _read_files(directory, required):
         """.strip().split()
 
     files = {}
+    required_found = False
+
     for path in Path(directory).glob("*"):
         if path.is_file():
             include = True
             for ignore in ignore_list:
-                if ignore in str(path):
+                if ignore in path.name:
                     include = False
                     break
             if include:
                 files[path.name] = _read_file(path)
+                if required in path.name:
+                    required_found = True
 
-    if required not in files.keys():
+    if not required_found:
         click.echo(click.style("\nERROR: ", fg="red"), nl=False)
         click.echo("Cannot find a file named `{file}`".format(file=required))
         sys.exit()
