@@ -149,7 +149,10 @@ def tradehook_create(options, from_update=False):
     while not config_file_found:
         config_file = inputs.path(
             "Path to Tradehook configuration file", validator="file")
-        config_file_found = Path(config_file).exists()
+        config_file_found = Path(config_file).exists() and utils.reversed_in(
+            [".json", ".yaml"], config_file, match="any")
+        if not config_file_found:
+            click.echo("Invalid file format")
 
     selected_strategies = inputs.checkboxes(
         "Attach to (optional, can be done later)", list(
@@ -278,7 +281,7 @@ def tradehook_attach(options):
 
         # return
         payload['strategies'] = inputs.checkboxes(
-            "Assign Tradehook to", list(strategies.values()))
+            "Assign Tradehook to", list(strategies.keys()))
 
     payload["strategies"] = list(set(payload["strategies"]))
 
@@ -302,6 +305,10 @@ def tradehook_attach(options):
             f"The Tradehook `{tradehook}` is now attached to:")
     click.echo(" - "+"\n - ".join(payload["strategies"]))
 
+    if errors:
+        click.echo("\nErrors:")
+        click.echo(utils.to_table(errors))
+
 
 def tradehook_detach(options):
     tradehook = options.first("tradehook")
@@ -343,7 +350,7 @@ def tradehook_detach(options):
 
         # return
         payload['strategies'] = inputs.checkboxes(
-            "Assign Tradehook to", list(strategies.values()))
+            "Assign Tradehook to", list(strategies.keys()))
 
     payload["strategies"] = list(set(payload["strategies"]))
 
@@ -366,6 +373,10 @@ def tradehook_detach(options):
             f"The Tradehook `{tradehook}` is now attached to:")
     click.echo(" - "+"\n - ".join(payload["strategies"]))
 
+    if errors:
+        click.echo("\nErrors:")
+        click.echo(utils.to_table(errors))
+
 
 def tradehook_delete(options):
     tradehook = options.first("tradehook")
