@@ -6,8 +6,12 @@ from .. import utils
 from . import crud
 
 
+try:
+    command = sys.argv[1]
+except:
+    command = ""
 commands = {
-    "ls": "  Retreive " + sys.argv[1] + " history: [--account|-a {ACCOUNT_ID}] [--strategy|-s {STRATEGY_ID}] [--start {DATETIME}] [--end {DATETIME}]",
+    "ls": "  Retreive " + command + " history: [--account|-a {ACCOUNT_ID}] [--strategy|-s {STRATEGY_ID}] [--start {DATETIME}] [--end {DATETIME}]",
 }
 
 rules = utils.args_actions()
